|PyPI Version| |Build Status| |Lint Status| |Coverage Status| |Python Version|

This Python package provides `Babel extractors <http://babel.pocoo.org/en/latest/messages.html>`__ and translation methods for standards like:

* Open Contracting Data Standard (OCDS), plus its extensions and profiles
* Open Contracting for Infrastructure Data Standard (OC4IDS)
* Beneficial Ownership Data Standard (BODS)
* Social Investment Data Lab Specification (SEDL)

If you are viewing this on GitHub or PyPi, open the `full documentation <https://ocds-babel.readthedocs.io/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ocds-babel.svg
   :target: https://pypi.org/project/ocds-babel/
.. |Build Status| image:: https://github.com/open-contracting/ocds-babel/workflows/CI/badge.svg
.. |Lint Status| image:: https://github.com/open-contracting/ocds-babel/workflows/Lint/badge.svg
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/ocds-babel/badge.png?branch=master
   :target: https://coveralls.io/github/open-contracting/ocds-babel?branch=master
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ocds-babel.svg
   :target: https://pypi.org/project/ocds-babel/
